#!/usr/bin/bash

function print_usage {

   echo "Usage:"
   echo
   echo "  sh whitelist-plugins.sh <command>"
   echo
   echo "Commands:"
   echo
   echo "  apply    Configures a white-list of well-known compatible plugins as the"
   echo "           only plugins allowed to deploy on the vSphere Client."
   echo
   echo "  revert   Reverts the previously configured white-list of plugins by"
   echo "           restoring the original compatibility-matrix.xml or creating a new"
   echo "           one allowing any plugin to deploy."
   echo 
   echo "To print the current message:"
   echo
   echo "  sh whitelist-plugins.sh --help"
   echo

}

if [ ! $# -eq 1 ]; then

   echo "Invalid number of arguments."
   echo
   print_usage

elif [ "$1" = "apply" ]; then

   echo "White-listing compatible plugins..."
   echo
   echo "Stopping vsphere-client service..."
   service-control --stop vsphere-client
   echo "Stopped vsphere-client service."
   echo

   if [ ! -f $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml.orig ]; then
      mv $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml.orig
      if [ $? -eq 0 ]; then 
         echo "Backed up $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml as $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml.orig."
      fi
   else
      if [ -f $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml ]; then
         echo "Found existing $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml.orig. Will not overwrite the file."
      fi
   fi
   echo

   # Replacing the plugin compatibility matrix with a whitelist one.
   echo '<Matrix>
      <pluginsCompatibility>
         <!-- ###VMWARE_KB_WHITELIST### -->
         <PluginPackage id="com.vmware.vsphere.(client|ds|ssoadminui|client.modules|client.srupload|client.telemetry)" status="compatible"/>
         <PluginPackage id="com.vmware.ds" status="compatible"/>
         <PluginPackage id="com.vmware.ssoadminui" status="compatible"/>
         <PluginPackage id="com.vmware.license.client" status="compatible"/>
         <PluginPackage id="com.vmware.opsmgmt.client" status="compatible"/>
         <PluginPackage id="com.vmware.vsan.health" status="compatible"/>
         <PluginPackage id="com.vmware.vsphere.client.h5vsan" status="compatible"/>
         <PluginPackage id="com.vmware.vcIntegrity.vcIntegrity" status="compatible"/>
         <PluginPackage id="com.vmware.vum.client" status="compatible"/>
         <PluginPackage id="com.vmware.imagebuilder.imagebuilder" version="[6.7.0,)" status="compatible"/>
         <PluginPackage id="com.vmware.vca.marketing.ngc.ui" status="compatible"/>
         <PluginPackage id="com.vmware.vco" version="[6.5.0,)" status="compatible"/>
         <PluginPackage id="com.vmware.vrops.install" status="compatible"/>
         <PluginPackage id="com.vmware.fallback.mixed" status="compatible"/>
         <!-- Known compatible plugins -->
         <PluginPackage id="com.vmware.vrUi" status="compatible"/>
         <PluginPackage id="com.nimblestorage.hi" version="[5.0.0,)" status="compatible"/>
         <PluginPackage id="com.dell.plugin.OpenManage_Integration_for_VMware_vCenter_WebClient" version="[4.2.0,)" status="compatible"/>
         <!-- TODO: Add more plugins here to enable them in the vSphere Client -->

         <PluginPackage id=".*" status="incompatible"/>

      </pluginsCompatibility>
   </Matrix>' > $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml
   chown vsphere-client $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml
   echo $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml saved.
   echo
   echo Starting vsphere-client service...
   service-control --start vsphere-client

elif [ "$1" = "revert" ]; then

   echo "Reverting the plugin white-list..."
   echo
   echo "Stopping vsphere-client service..."
   service-control --stop vsphere-client
   echo "Stopped vsphere-client service."
   echo

   if [ -f $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml.orig ]; then
      mv -f $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml.orig $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml
      echo "Reverted the orignal version of $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml."
   else
      echo '<Matrix>
         <pluginsCompatibility>

         </pluginsCompatibility>
      </Matrix>' > $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml
      echo "Created an empty $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml."
   fi
   chown vsphere-client $VMWARE_CFG_DIR/vsphere-client/compatibility-matrix.xml
   echo

   echo Starting vsphere-client service...
   service-control --start vsphere-client

elif [ "$1" = "--help" ]; then

   print_usage

else

   echo "Invalid argument $1."
   echo
   print_usage

fi
